@@ -64,7 +64,7 @@ void PluginKateTextFilter::addView(Kate::MainWindow *win)
     PluginView *view = new PluginView ();
 
     (void)  new TDEAction ( i18n("Filter Te&xt..."), /*"edit_filter",*/ CTRL + Key_Backslash, this,
-  TQT_SLOT( slotEditFilter() ), view->actionCollection(), "edit_filter" );
+  TQ_SLOT( slotEditFilter() ), view->actionCollection(), "edit_filter" );
 
     view->setInstance (new TDEInstance("kate"));
     view->setXMLFile( "plugins/katetextfilter/ui.rc" );
@@ -283,17 +283,17 @@ void PluginKateTextFilter::runFilter( Kate::View *kv, const TQString &filter )
   {
     m_pFilterShellProcess = new KShellProcess;
 
-    connect ( m_pFilterShellProcess, TQT_SIGNAL(wroteStdin(TDEProcess *)),
-              this, TQT_SLOT(slotFilterCloseStdin (TDEProcess *)));
+    connect ( m_pFilterShellProcess, TQ_SIGNAL(wroteStdin(TDEProcess *)),
+              this, TQ_SLOT(slotFilterCloseStdin (TDEProcess *)));
 
-    connect ( m_pFilterShellProcess, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
-              this, TQT_SLOT(slotFilterReceivedStdout(TDEProcess*,char*,int)) );
+    connect ( m_pFilterShellProcess, TQ_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+              this, TQ_SLOT(slotFilterReceivedStdout(TDEProcess*,char*,int)) );
 
-    connect ( m_pFilterShellProcess, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
-              this, TQT_SLOT(slotFilterReceivedStderr(TDEProcess*,char*,int)) );
+    connect ( m_pFilterShellProcess, TQ_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+              this, TQ_SLOT(slotFilterReceivedStderr(TDEProcess*,char*,int)) );
 
-    connect ( m_pFilterShellProcess, TQT_SIGNAL(processExited(TDEProcess*)),
-              this, TQT_SLOT(slotFilterProcessExited(TDEProcess*) ) ) ;
+    connect ( m_pFilterShellProcess, TQ_SIGNAL(processExited(TDEProcess*)),
+              this, TQ_SLOT(slotFilterProcessExited(TDEProcess*) ) ) ;
   }
 
   slipInFilter (*m_pFilterShellProcess, *kv, filter);
