@@ -73,7 +73,7 @@ RsyncPlugin::RsyncPlugin (TQObject* parent, const char* name,
                 m_pSyncNow(0),
                 m_pSyncSetup(0)
 {
-  m_part = ::tqqt_cast<KonqDirPart*>(parent);
+  m_part = ::tqt_cast<KonqDirPart*>(parent);
 
   if ( !m_part || !m_part->scrollWidget() )
     return;
@@ -88,13 +88,13 @@ RsyncPlugin::RsyncPlugin (TQObject* parent, const char* name,
 
   m_rSync = new KRsync(parent, name);
 
-  connect (m_part, TQT_SIGNAL(aboutToOpenURL()), TQT_SLOT(slotOpenURL()));
+  connect (m_part, TQ_SIGNAL(aboutToOpenURL()), TQ_SLOT(slotOpenURL()));
 
-  connect(m_pSyncNow, TQT_SIGNAL(activated()), this, TQT_SLOT(slotSync()));
-  connect(m_pSyncSetup, TQT_SIGNAL(activated()), this, TQT_SLOT(slotSetup()));
+  connect(m_pSyncNow, TQ_SIGNAL(activated()), this, TQ_SLOT(slotSync()));
+  connect(m_pSyncSetup, TQ_SIGNAL(activated()), this, TQ_SLOT(slotSetup()));
 
-  connect(m_rSync, TQT_SIGNAL(setupDone()), this, TQT_SLOT(slotSetupDone()));
-  connect(m_rSync, TQT_SIGNAL(transferDone()), this, TQT_SLOT(slotTransferDone()));
+  connect(m_rSync, TQ_SIGNAL(setupDone()), this, TQ_SLOT(slotSetupDone()));
+  connect(m_rSync, TQ_SIGNAL(transferDone()), this, TQ_SLOT(slotTransferDone()));
 
   m_rSync->loadSettings();
 }
